let SessionLoad = 1
let s:so_save = &g:so | let s:siso_save = &g:siso | setg so=0 siso=0 | setl so=-1 siso=-1
let v:this_session=expand("<sfile>:p")
silent only
silent tabonly
cd ~/other/own_github/test-database-temp
if expand('%') == '' && !&modified && line('$') <= 1 && getline(1) == ''
  let s:wipebuf = bufnr('%')
endif
let s:shortmess_save = &shortmess
if &shortmess =~ 'A'
  set shortmess=aoOA
else
  set shortmess=aoO
endif
badd +108 dist.ini
badd +0 t/test-all-databases.t
badd +0 lib/Test/Database/Temp.pm
badd +20 ~/other/own_github/test-database-temp/.lvimrc
badd +2 README.md
badd +0 MANIFEST.SKIP
badd +0 .gitignore
argglobal
%argdel
$argadd dist.ini
set stal=2
tabnew +setlocal\ bufhidden=wipe
tabrewind
edit dist.ini
let s:save_splitbelow = &splitbelow
let s:save_splitright = &splitright
set splitbelow splitright
wincmd _ | wincmd |
vsplit
1wincmd h
wincmd _ | wincmd |
split
1wincmd k
wincmd w
wincmd w
let &splitbelow = s:save_splitbelow
let &splitright = s:save_splitright
wincmd t
let s:save_winminheight = &winminheight
let s:save_winminwidth = &winminwidth
set winminheight=0
set winheight=1
set winminwidth=0
set winwidth=1
exe '1resize ' . ((&lines * 43 + 44) / 88)
exe 'vert 1resize ' . ((&columns * 157 + 158) / 317)
exe '2resize ' . ((&lines * 41 + 44) / 88)
exe 'vert 2resize ' . ((&columns * 157 + 158) / 317)
exe 'vert 3resize ' . ((&columns * 159 + 158) / 317)
argglobal
balt t/test-all-databases.t
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 63 - ((25 * winheight(0) + 21) / 43)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 63
normal! 0
wincmd w
argglobal
if bufexists(fnamemodify("t/test-all-databases.t", ":p")) | buffer t/test-all-databases.t | else | edit t/test-all-databases.t | endif
if &buftype ==# 'terminal'
  silent file t/test-all-databases.t
endif
balt dist.ini
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 112 - ((40 * winheight(0) + 20) / 41)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 112
normal! 0
wincmd w
argglobal
if bufexists(fnamemodify("lib/Test/Database/Temp.pm", ":p")) | buffer lib/Test/Database/Temp.pm | else | edit lib/Test/Database/Temp.pm | endif
if &buftype ==# 'terminal'
  silent file lib/Test/Database/Temp.pm
endif
balt README.md
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 126 - ((4 * winheight(0) + 42) / 85)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 126
normal! 05|
wincmd w
3wincmd w
exe '1resize ' . ((&lines * 43 + 44) / 88)
exe 'vert 1resize ' . ((&columns * 157 + 158) / 317)
exe '2resize ' . ((&lines * 41 + 44) / 88)
exe 'vert 2resize ' . ((&columns * 157 + 158) / 317)
exe 'vert 3resize ' . ((&columns * 159 + 158) / 317)
tabnext
edit .gitignore
let s:save_splitbelow = &splitbelow
let s:save_splitright = &splitright
set splitbelow splitright
wincmd _ | wincmd |
vsplit
1wincmd h
wincmd w
let &splitbelow = s:save_splitbelow
let &splitright = s:save_splitright
wincmd t
let s:save_winminheight = &winminheight
let s:save_winminwidth = &winminwidth
set winminheight=0
set winheight=1
set winminwidth=0
set winwidth=1
exe 'vert 1resize ' . ((&columns * 158 + 158) / 317)
exe 'vert 2resize ' . ((&columns * 158 + 158) / 317)
argglobal
balt MANIFEST.SKIP
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 19 - ((18 * winheight(0) + 42) / 85)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 19
normal! 020|
wincmd w
argglobal
if bufexists(fnamemodify("MANIFEST.SKIP", ":p")) | buffer MANIFEST.SKIP | else | edit MANIFEST.SKIP | endif
if &buftype ==# 'terminal'
  silent file MANIFEST.SKIP
endif
balt .gitignore
setlocal fdm=manual
setlocal fde=0
setlocal fmr={{{,}}}
setlocal fdi=#
setlocal fdl=0
setlocal fml=1
setlocal fdn=20
setlocal fen
silent! normal! zE
let &fdl = &fdl
let s:l = 15 - ((14 * winheight(0) + 42) / 85)
if s:l < 1 | let s:l = 1 | endif
keepjumps exe s:l
normal! zt
keepjumps 15
normal! 011|
wincmd w
exe 'vert 1resize ' . ((&columns * 158 + 158) / 317)
exe 'vert 2resize ' . ((&columns * 158 + 158) / 317)
tabnext 1
set stal=1
if exists('s:wipebuf') && len(win_findbuf(s:wipebuf)) == 0 && getbufvar(s:wipebuf, '&buftype') isnot# 'terminal'
  silent exe 'bwipe ' . s:wipebuf
endif
unlet! s:wipebuf
set winheight=1 winwidth=20
let &shortmess = s:shortmess_save
let &winminheight = s:save_winminheight
let &winminwidth = s:save_winminwidth
let s:sx = expand("<sfile>:p:r")."x.vim"
if filereadable(s:sx)
  exe "source " . fnameescape(s:sx)
endif
let &g:so = s:so_save | let &g:siso = s:siso_save
set hlsearch
doautoall SessionLoadPost
unlet SessionLoad
" vim: set ft=vim :
